@@ -9,7 +9,7 @@ import jax.numpy as jnp
 
 @partial(jax.custom_vjp, nondiff_argnums=(0,))
 def einsum(eq, *x):
-    return jnp.einsum(eq, *x, optimize='optimal')
+    return jnp.einsum(eq, *x, optimize="optimal")
 
 
 def _ein_fwd(eq, *x):
@@ -18,10 +18,10 @@ def _ein_fwd(eq, *x):
 
 def _ein_bwd(eq, res, g):
     # TODO handle indices appearing in a single input like 'ij->i' or 'ii->'
-    inputs, out = eq.split('->')
-    inputs = inputs.split(',')
+    inputs, out = eq.split("->")
+    inputs = inputs.split(",")
     return tuple(
-        einsum(f"{','.join(inputs[:i] + inputs[i + 1:] + [out])}->{inputs[i]}", *res[:i], *res[i + 1:], g)
+        einsum(f"{','.join(inputs[:i] + inputs[i + 1:] + [out])}->{inputs[i]}", *res[:i], *res[i + 1 :], g)
         for i in range(len(res))
     )
 
