@@ -25,7 +25,7 @@ class Convolution(hk.Module):
         irreps_sh: Irreps,
         diameter: float,
         num_radial_basis: Union[int, Dict[int, int]],
-        steps: Tuple[float, float, float],
+        steps: Union[Tuple[float, float, float], Tuple[Tuple[float, float, float], jnp.ndarray]],
         *,
         relative_starts: Union[float, Dict[int, float]] = 0.0,
         padding="SAME",
@@ -46,31 +46,32 @@ class Convolution(hk.Module):
         super().__init__()
 
         if isinstance(num_radial_basis, int):
-            num_radial_basis = defaultdict(lambda: num_radial_basis)
+            self.num_radial_basis = defaultdict(lambda: num_radial_basis)
+        else:
+            self.num_radial_basis = num_radial_basis
 
         if isinstance(relative_starts, (float, int)):
-            relative_starts = defaultdict(lambda: relative_starts)
+            self.relative_starts = defaultdict(lambda: relative_starts)
+        else:
+            self.relative_starts = relative_starts
 
         self.irreps_in = Irreps(irreps_in) if irreps_in is not None else None
         self.irreps_out = Irreps(irreps_out)
         self.irreps_sh = Irreps(irreps_sh)
         self.diameter = diameter
-        self.num_radial_basis = num_radial_basis
-        self.relative_starts = relative_starts
-        self.steps = steps
         self.padding = padding
 
-        with jax.ensure_compile_time_eval():
+        def f(steps1, steps2):
             r = self.diameter / 2
 
-            s = math.floor(r / self.steps[0])
-            x = jnp.arange(-s, s + 1.0) * self.steps[0]
+            s = math.floor(r / steps1[0])
+            x = jnp.arange(-s, s + 1.0) * steps2[0]
 
-            s = math.floor(r / self.steps[1])
-            y = jnp.arange(-s, s + 1.0) * self.steps[1]
+            s = math.floor(r / steps1[1])
+            y = jnp.arange(-s, s + 1.0) * steps2[1]
 
-            s = math.floor(r / self.steps[2])
-            z = jnp.arange(-s, s + 1.0) * self.steps[2]
+            s = math.floor(r / steps1[2])
+            z = jnp.arange(-s, s + 1.0) * steps2[2]
 
             self.lattice = jnp.stack(jnp.meshgrid(x, y, z, indexing="ij"), axis=-1)  # [x, y, z, R^3]
 
@@ -78,6 +79,12 @@ class Convolution(hk.Module):
                 irreps_out=self.irreps_sh, input=self.lattice, normalize=True, normalization="component"
             )  # [x, y, z, irreps_sh.dim]
 
+        if isinstance(steps[0], tuple):
+            f(steps[0], steps[1])
+        else:
+            with jax.ensure_compile_time_eval():
+                f(steps, steps)
+
     def tp_weight(
         self,
         i_in: int,
