@@ -1,3 +1,4 @@
+import inspect
 from functools import wraps
 
 from e3nn_jax import Irreps, IrrepsData
@@ -5,9 +6,10 @@ from e3nn_jax import Irreps, IrrepsData
 
 def overload_for_irreps_without_data(irrepsdata_argnums=None, irrepsdata_argnames=None, shape=()):
     def decorator(func):
+        # TODO: this is very bad to use a function from the internal API
         from jax._src.api import _infer_argnums_and_argnames
 
-        argnums, argnames = _infer_argnums_and_argnames(func, irrepsdata_argnums, irrepsdata_argnames)
+        argnums, argnames = _infer_argnums_and_argnames(inspect.signature(func), irrepsdata_argnums, irrepsdata_argnames)
 
         @wraps(func)
         def wrapper(*args, **kwargs):
